==> cauldron_notebook-0.1.1-py2.py3-none-any.whl: cauldron/test/cli/server/routes/synchronize/test_sync_file.py <==
import os

import cauldron
from cauldron.cli import sync
from cauldron.test import support
from cauldron.test.support.flask_scaffolds import FlaskResultsTest


class TestSyncFile(FlaskResultsTest):
    """ """

    def test_no_args(self):
        """ should error without arguments """

        opened = self.post('/sync-file')
        self.assertEqual(opened.flask.status_code, 200)

        response = opened.response
        self.assert_has_error_code(response, 'INVALID_ARGS')

    def test_missing_relative_path(self):
        """ should error without relative_path argument """

        opened = self.post('/sync-file', {'chunk': 'abc'})

        response = opened.response
        self.assert_has_error_code(response, 'INVALID_ARGS')

    def test_missing_chunk(self):
        """ should error without source directory argument """

        opened = self.post('/sync-file', {'relative_path': 'abc'})

        response = opened.response
        self.assert_has_error_code(response, 'INVALID_ARGS')

    def test_no_project(self):
        """ should error without source directory argument """

        opened = self.post('/sync-file', {
            'relative_path': 'abc',
            'chunk': 'abcdefg'
        })

        response = opened.response
        self.assert_has_error_code(response, 'NO_OPEN_PROJECT')

    def test_valid(self):
        """ should synchronize file remotely """

        support.create_project(self, 'peter')
        project = cauldron.project.internal_project

        response = support.run_remote_command(
            'open "{}"'.format(project.source_directory)
        )
        self.assert_no_errors(response)
        project = cauldron.project.internal_project

        posted = self.post('/sync-file', {
            'relative_path': 'test.md',
            'chunk': sync.io.pack_chunk(b'abcdefg')
        })
        self.assert_no_errors(posted.response)

        written_path = os.path.join(project.source_directory, 'test.md')
        self.assertTrue(os.path.exists(written_path))

        support.run_remote_command('close')

==> cauldron_notebook-0.4.2-py2.py3-none-any.whl: cauldron/test/cli/server/routes/synchronize/test_sync_file.py <==
import os

import cauldron
from cauldron.cli import sync
from cauldron.test import support
from cauldron.test.support.flask_scaffolds import FlaskResultsTest


class TestSyncFile(FlaskResultsTest):
    """ """

    def test_no_args(self):
        """ should error without arguments """

        opened = self.post('/sync-file')
        self.assertEqual(opened.flask.status_code, 200)

        response = opened.response
        self.assert_has_error_code(response, 'INVALID_ARGS')

    def test_missing_relative_path(self):
        """ should error without relative_path argument """

        opened = self.post('/sync-file', {'chunk': 'abc'})

        response = opened.response
        self.assert_has_error_code(response, 'INVALID_ARGS')

    def test_missing_chunk(self):
        """ should error without source directory argument """

        opened = self.post('/sync-file', {'relative_path': 'abc'})

        response = opened.response
        self.assert_has_error_code(response, 'INVALID_ARGS')

    def test_no_project(self):
        """ should error without source directory argument """

        opened = self.post('/sync-file', {
            'relative_path': 'abc',
            'chunk': 'abcdefg'
        })

        response = opened.response
        self.assert_has_error_code(response, 'NO_OPEN_PROJECT')

    def test_valid(self):
        """ should synchronize file remotely """

        support.create_project(self, 'peter')
        project = cauldron.project.get_internal_project()

        response = support.run_remote_command(
            'open "{}"'.format(project.source_directory)
        )
        self.assert_no_errors(response)
        project = cauldron.project.get_internal_project()

        posted = self.post('/sync-file', {
            'relative_path': 'test.md',
            'chunk': sync.io.pack_chunk(b'abcdefg')
        })
        self.assert_no_errors(posted.response)

        written_path = os.path.join(project.source_directory, 'test.md')
        self.assertTrue(os.path.exists(written_path))

        support.run_remote_command('close')
